@@ -1,7 +1,6 @@
 use crate::attributes::*;
 use crate::error::*;
 
-use anyhow::Result;
 use subtle::ConstantTimeEq;
 
 // check_size returns ErrAttrSizeInvalid if got is not equal to expected.
@@ -9,18 +8,18 @@ pub fn check_size(_at: AttrType, got: usize, expected: usize) -> Result<()> {
     if got == expected {
         Ok(())
     } else {
-        Err(Error::ErrAttributeSizeInvalid.into())
+        Err(Error::ErrAttributeSizeInvalid)
     }
 }
 
 // is_attr_size_invalid returns true if error means that attribute size is invalid.
-pub fn is_attr_size_invalid(err: &anyhow::Error) -> bool {
-    Error::ErrAttributeSizeInvalid.equal(err)
+pub fn is_attr_size_invalid(err: &Error) -> bool {
+    Error::ErrAttributeSizeInvalid == *err
 }
 
 pub(crate) fn check_hmac(got: &[u8], expected: &[u8]) -> Result<()> {
     if got.ct_eq(expected).unwrap_u8() != 1 {
-        Err(Error::ErrIntegrityMismatch.into())
+        Err(Error::ErrIntegrityMismatch)
     } else {
         Ok(())
     }
@@ -30,7 +29,7 @@ pub(crate) fn check_fingerprint(got: u32, expected: u32) -> Result<()> {
     if got == expected {
         Ok(())
     } else {
-        Err(Error::ErrFingerprintMismatch.into())
+        Err(Error::ErrFingerprintMismatch)
     }
 }
 
@@ -39,11 +38,11 @@ pub fn check_overflow(_at: AttrType, got: usize, max: usize) -> Result<()> {
     if got <= max {
         Ok(())
     } else {
-        Err(Error::ErrAttributeSizeOverflow.into())
+        Err(Error::ErrAttributeSizeOverflow)
     }
 }
 
 // is_attr_size_overflow returns true if error means that attribute size is too big.
-pub fn is_attr_size_overflow(err: &anyhow::Error) -> bool {
-    Error::ErrAttributeSizeOverflow.equal(err)
+pub fn is_attr_size_overflow(err: &Error) -> bool {
+    Error::ErrAttributeSizeOverflow == *err
 }
