@@ -1,6 +1,13 @@
 use thiserror::Error;
 
+use std::io;
+use std::string::FromUtf8Error;
+use tokio::sync::mpsc::error::SendError as MpscSendError;
+
+pub type Result<T> = std::result::Result<T, Error>;
+
 #[derive(Debug, Error, PartialEq)]
+#[non_exhaustive]
 pub enum Error {
     #[error("attribute not found")]
     ErrAttributeNotFound,
@@ -52,14 +59,40 @@ pub enum Error {
     ErrSchemeType,
     #[error("invalid hostname")]
     ErrHost,
-
-    #[allow(non_camel_case_types)]
     #[error("{0}")]
-    new(String),
+    Other(String),
+    #[error("url parse: {0}")]
+    Url(#[from] url::ParseError),
+    #[error("utf8: {0}")]
+    Utf8(#[from] FromUtf8Error),
+    #[error("{0}")]
+    Io(#[source] IoError),
+    #[error("mpsc send: {0}")]
+    MpscSend(String),
+    #[error("{0}")]
+    Util(#[from] util::Error),
 }
 
-impl Error {
-    pub fn equal(&self, err: &anyhow::Error) -> bool {
-        err.downcast_ref::<Self>().map_or(false, |e| e == self)
+#[derive(Debug, Error)]
+#[error("io error: {0}")]
+pub struct IoError(#[from] pub io::Error);
+
+// Workaround for wanting PartialEq for io::Error.
+impl PartialEq for IoError {
+    fn eq(&self, other: &Self) -> bool {
+        self.0.kind() == other.0.kind()
+    }
+}
+
+impl From<io::Error> for Error {
+    fn from(e: io::Error) -> Self {
+        Error::Io(IoError(e))
+    }
+}
+
+// Because Tokio SendError is parameterized, we sadly lose the backtrace.
+impl<T> From<MpscSendError<T>> for Error {
+    fn from(e: MpscSendError<T>) -> Self {
+        Error::MpscSend(e.to_string())
     }
 }
