@@ -5,7 +5,6 @@ use crate::attributes::*;
 use crate::error::*;
 use crate::message::*;
 
-use anyhow::Result;
 use std::fmt;
 
 // UnknownAttributes represents UNKNOWN-ATTRIBUTES attribute.
@@ -48,7 +47,7 @@ impl Getter for UnknownAttributes {
     fn get_from(&mut self, m: &Message) -> Result<()> {
         let v = m.get(ATTR_UNKNOWN_ATTRIBUTES)?;
         if v.len() % ATTR_TYPE_SIZE != 0 {
-            return Err(Error::ErrBadUnknownAttrsSize.into());
+            return Err(Error::ErrBadUnknownAttrsSize);
         }
         self.0.clear();
         let mut first = 0usize;
