@@ -3,7 +3,6 @@ mod uri_test;
 
 use crate::error::*;
 
-use anyhow::Result;
 use std::fmt;
 
 // SCHEME definitions from RFC 7064 Section 3.2.
@@ -40,7 +39,7 @@ impl Uri {
     pub fn parse_uri(raw: &str) -> Result<Self> {
         // work around for url crate
         if raw.contains("//") {
-            return Err(Error::ErrInvalidUrl.into());
+            return Err(Error::ErrInvalidUrl);
         }
 
         let mut s = raw.to_string();
@@ -48,14 +47,14 @@ impl Uri {
         if let Some(p) = pos {
             s.replace_range(p..p + 1, "://");
         } else {
-            return Err(Error::ErrSchemeType.into());
+            return Err(Error::ErrSchemeType);
         }
 
         let raw_parts = url::Url::parse(&s)?;
 
         let scheme = raw_parts.scheme().into();
         if scheme != SCHEME && scheme != SCHEME_SECURE {
-            return Err(Error::ErrSchemeType.into());
+            return Err(Error::ErrSchemeType);
         }
 
         let host = if let Some(host) = raw_parts.host_str() {
@@ -64,7 +63,7 @@ impl Uri {
                 .trim_end_matches(']')
                 .to_owned()
         } else {
-            return Err(Error::ErrHost.into());
+            return Err(Error::ErrHost);
         };
 
         let port = raw_parts.port();
